@@ -326,6 +326,25 @@ public class JenaLMS implements ServiceLifeCycle {
         System.out.println("JenaLMS.lmsInitialize(). called!");
         System.out.println("    userID: "+userID);
         System.out.println("    tmURL : "+tmURL);
+
+        String time = date2string(new Date());
+        String req = "PREFIX : <http://x314.do-johodai.ac.jp/JenaLMS/>\n";
+         req = req + "PREFIX dc: <http://purl.org/dc/elements/1.1/>\n";
+         req = req + "PREFIX foaf: <http://xmlns.com/foaf/0.1/>\n";
+         req = req + "CONSTRUCT {\n";
+         req = req + "  [] a :tm_open_event ;\n";
+         req = req + "     :user ?user ;\n";
+         req = req + "     :content ?content ;\n";
+         req = req + "     dc:date '"+time+"'^^<http://www.w3.org/2001/XMLSchema#dateTime> .\n";
+         req = req + "}\n";
+         req = req + "WHERE {\n";
+         req = req + "  ?user a foaf:Person ;\n";
+         req = req + "      :userID '"+userID+"' .\n";
+         req = req + "  ?content a :edu_material ;\n";
+         req = req + "      :url '"+tmURL+"' .\n";
+         req = req + "}\n";
+        engine.insertSPARQL(req);
+
         return "dummy";
     }
 
@@ -338,6 +357,25 @@ public class JenaLMS implements ServiceLifeCycle {
         System.out.println("JenaLMS.lmsFinish(). called!");
         System.out.println("    userID: "+userID);
         System.out.println("    tmURL : "+tmURL);
+
+        String time = date2string(new Date());
+        String req = "PREFIX : <http://x314.do-johodai.ac.jp/JenaLMS/>\n";
+         req = req + "PREFIX dc: <http://purl.org/dc/elements/1.1/>\n";
+         req = req + "PREFIX foaf: <http://xmlns.com/foaf/0.1/>\n";
+         req = req + "CONSTRUCT {\n";
+         req = req + "  [] a :tm_close_event ;\n";
+         req = req + "     :user ?user ;\n";
+         req = req + "     :content ?content ;\n";
+         req = req + "     dc:date '"+time+"'^^<http://www.w3.org/2001/XMLSchema#dateTime> .\n";
+         req = req + "}\n";
+         req = req + "WHERE {\n";
+         req = req + "  ?user a foaf:Person ;\n";
+         req = req + "      :userID '"+userID+"' .\n";
+         req = req + "  ?content a :edu_material ;\n";
+         req = req + "      :url '"+tmURL+"' .\n";
+         req = req + "}\n";
+        engine.insertSPARQL(req);
+
         return "dummy";
     }
 
@@ -564,7 +602,6 @@ public class JenaLMS implements ServiceLifeCycle {
                 req = req + "@prefix l: <http://x314.do-johodai.ac.jp/JenaLMS/learnings/> .\n";
                 req = req + "@prefix dc: <http://purl.org/dc/elements/1.1/> .\n";
                 req = req + "@prefix dct: <http://purl.org/dc/terms/> .\n";
-                req = req + "PREFIX owl: <http://www.w3.org/2002/07/owl#>\n";
                 req = req + "[] a :"+md[i].type+" ;\n";
                 req = req + "    :url '"+md[i].url+"' ;\n";
                 req = req + "    dc:title '"+md[i].title+"' ;\n";
